@@ -23,7 +23,7 @@ def set_attribute_path(obj, attribute_path: List[str], value: Any):
     if len(attribute_path) == 1:
         return setattr(obj, attribute_path[0], value)
 
-    return get_attribute_path(getattr(obj, attribute_path[0]), attribute_path[1:])
+    return set_attribute_path(getattr(obj, attribute_path[0]), attribute_path[1:], value)
 
 
 def is_json_serializable(value: Any) -> bool:
@@ -205,8 +205,11 @@ class Server(gateway.GatewayClient):
                 return utils.build_response(status=messages_pb2.Status.METHOD)
 
             try:
-                serialized_data = pickle.dumps(data)
-                return utils.build_response(serialized_data=serialized_data)
+                if utils.serializable(data) and '.' not in attribute_path:
+                    serialized_data = pickle.dumps(data)
+                    return utils.build_response(serialized_data=serialized_data)
+                else:
+                    return utils.build_response(status=messages_pb2.Status.PROXY)
             except (pickle.PickleError, TypeError):
                 return utils.build_response(status=messages_pb2.Status.PROXY)
         except Exception as err:
